Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/prusa3d/PrusaSlicer.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorbubnikv <bubnikv@gmail.com>2018-02-14 20:42:09 +0300
committerbubnikv <bubnikv@gmail.com>2018-02-14 20:42:09 +0300
commit3a6436f6f0369e57708c2174d7974eb6e4047b94 (patch)
tree237d133e7bf3b8cc8eae5dd5caa5dd18e6581001 /xs/src/libslic3r/Print.hpp
parentf38e0f2b4fd756c01111a47aac193a54d12d4739 (diff)
Split the GCodePreviewData from the GCodeAnalyzer,
as in the next step the GCodePreviewData will be exported to Perl.
Diffstat (limited to 'xs/src/libslic3r/Print.hpp')
-rw-r--r--xs/src/libslic3r/Print.hpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/xs/src/libslic3r/Print.hpp b/xs/src/libslic3r/Print.hpp
index da94917fc..f08b4ec15 100644
--- a/xs/src/libslic3r/Print.hpp
+++ b/xs/src/libslic3r/Print.hpp
@@ -15,7 +15,7 @@
#include "Slicing.hpp"
#include "GCode/ToolOrdering.hpp"
#include "GCode/WipeTower.hpp"
-#include "GCode/Analyzer.hpp"
+#include "GCode/PreviewData.hpp"
#include "tbb/atomic.h"
@@ -241,7 +241,7 @@ public:
// ordered collections of extrusion paths to build skirt loops and brim
ExtrusionEntityCollection skirt, brim;
- GCodeAnalyzer::PreviewData gcode_preview;
+ GCodePreviewData gcode_preview;
Print() : total_used_filament(0), total_extruded_volume(0) { restart(); }
~Print() { clear_objects(); }
@@ -272,7 +272,7 @@ public:
// <role_3>, <color_3>,
// ...
// <role_N>, <color_N> };
// where <role_X> should be a string from GCodeAnalyzer::PreviewData::Extrusion::Default_Extrusion_Role_Names[]
// and <color_X> an RGB color in hex format (i.e. red = FF0000)
void set_gcode_extrusion_paths_colors(const std::vector<std::string>& colors);
@@ -272,7 +272,7 @@ public:
// ...
// <role_N>, <color_N> };
- // where <role_X> should be a string from GCodeAnalyzer::PreviewData::Extrusion::Default_Extrusion_Role_Names[]
+ // where <role_X> should be a string from GCodePreviewData::Extrusion::Default_Extrusion_Role_Names[]
// and <color_X> an RGB color in hex format (i.e. red = FF0000)
void set_gcode_extrusion_paths_colors(const std::vector<std::string>& colors);